@@ -8,7 +8,18 @@ from openapi_django.openapi_utils.objects import OpenAPI
 
 class OpenApiFile(View):
     def get(self, request):
-        obj = OpenAPI.generate(root_urlconf=getattr(settings, "ROOT_URLCONF"), servers=['http://127.0.0.1:8000/'])
+
+        django_params = getattr(settings, 'OPENAPI_DJANGO') if hasattr(settings, 'OPENAPI_DJANGO') else {}
+
+        servers = django_params.get("servers", [])
+        title = django_params.get("title")
+        version = django_params.get("version")
+
+        if getattr(settings, 'DEBUG'):
+            servers.append(f'http://{request.META["HTTP_HOST"]}')
+
+        obj = OpenAPI.generate(
+            root_urlconf=getattr(settings, "ROOT_URLCONF"), servers=servers, title=title, version=version)
         response = HttpResponse(
             json.dumps(obj.json(), indent=2, ensure_ascii=False).encode('utf-8'), content_type='application/json')
         response['Content-Disposition'] = 'attachment; filename="openapi.json"'
